<?php

namespace Controller;

use Exception;
use Traits\TResponse;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DTO;
use Service\TaskTracking as TaskTrackingService;

class TaskTracking extends Simple
{

    use TResponse;

    /**
     * @var TaskTrackingService
     */
    private $taskTrackingService;

    /**
     * TaskTracking constructor.
     * @param TaskTrackingService
     */

    public function __construct(TaskTrackingService $taskTrackingService)
    {
        $this->taskTrackingService = $taskTrackingService;
    }

    public function findTaskTracking(DTO\Request $request, DTO\Response $response)
    {
        try {
            $param = $request->getParameters();
            $page = !empty($param['page']) ? $param['page']  : null;
            $limit = !empty($param['limit'])  ? $param['limit'] : null;
            $order = !empty($param['order'])  ? $param['order']  : null;
            $search = !empty($param['search'])  ? $param['search']  : null;
            $searchIn = !empty($param['search_in'])  ? $param['search_in']  : null;
            $find = !empty($param['find'])  ? $param['find']  : null;
            $dynamicFilter = !empty($param['dynamic_filter'])  ? $param['dynamic_filter'] : null;
            if(empty($dynamicFilter)){
                $data = [ 'data' => [], 'pagination' => [ 'limit' => $limit, 'page' => $page, 'total' => 0]];
            } else {
                $data = $this->taskTrackingService->findTaskTracking($dynamicFilter, $search, $searchIn, $find, $order, $page, $limit);
            }
            $this->sendResponse($data, 200);
        } catch (Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function infoTaskInTaskTracking(DTO\Request $request, DTO\Response $response){
        try {
            $params = $request->getParameters();
            $idTask = !empty($params['TASK_ID']) ? $params['TASK_ID'] : null;
            $resource = !empty($params['RESOURCE_T']) ? $params['RESOURCE_T'] :  null;
            $data = $this->taskTrackingService->getInfoTaskInTaskTracking($idTask, $resource);
            $this->sendResponse($data, 200);
        } catch(Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findAllStatusTaskTracking(DTO\Request $request, DTO\Response $response) {
        try {
            $data = $this->taskTrackingService->findAllStatusTaskTracking();
            $this->sendResponse($data, 200);
        } catch(Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
	}

    public function findAllIssuesFromFilterTaskTracking(DTO\Request $request, DTO\Response $response) {
        try {
        $data = $this->taskTrackingService->findAllIssuesFromFilterTaskTracking();
        $this->sendResponse($data, 200);
        } catch(Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
	}

    public function saveLabelTask(DTO\Request $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();
            $task = !empty($params['ID']) ? $params['ID'] : null;
            $labels = !empty($params['TASK_LABEL']) ? $params['TASK_LABEL'] : [];
            $taskResponse = !empty($params['TASK_RESPONSE']) ? $params['TASK_RESPONSE'] : null;
            $this->taskTrackingService->associateTaskAndLabels($task, $labels, null, true);
            $this->taskTrackingService->saveTaskReponse($task, $taskResponse);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
}