import { Modal, ModalService, FileInput, LoadingService } from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { Metadata, IEventParam, Http, Config } from '@zeedhi/core';
import { FileUpload } from '@/services/FileUpload';
import { DialogServiceCustom } from '@/services/DialogServiceCustom';

export class DocumentsTemplateController {
   private documentsTemplateModal!: Modal;

   private documentsTemplateModalAdd!: Modal;

   private tekGridInstance!: TekGrid;

   public idInputValue?: string;

   public createdByInputValue?: string;

   public createdAtInputValue?: string;

   public nameInputValue?: string;

   public typeInputValue?: string;

   public documentInputValue?: string;

   public baseUrl = '';

   public async createdModal() {
     this.documentsTemplateModal = await ModalService.createFromJson(
       'documentsTemplate/modal/modal',
       true,
     );
     this.documentsTemplateModalAdd = await ModalService.createFromJson(
        'documentsTemplate/modal/modalAdd',
        true,
      );
     this.tekGridInstance = Metadata.getInstance<TekGrid>('TekGrid_template_documentsTemplate-grid');
   }

   public openModalOnClick() {
    this.documentsTemplateModal.show();
    this.updateDetails();
  }

  public closeModal() {
    this.documentsTemplateModal.hide();
    }

    public closeModalAdd() {
        this.documentsTemplateModalAdd.hide();
    }

    public addGridRow({ event }: IEventParam<TekGrid>) {
        event?.preventDefault();
        this.documentsTemplateModalAdd.show();
    }

    public async formSubmit() {
      LoadingService.show();
      const fileInput: FileInput = Metadata.getInstance('fileInputUploadDocumentTemplateModal');
      if (fileInput.value) {
        const checkFile = fileInput.value.map((file: any) => {
          if (file.size < 50000000) {
            return FileUpload.buildFileSendObject(file);
          }
          return false;
        });
        Promise.all(checkFile).then(async (fileArray) => {
          try {
            await Http.post('/updateDocumentsTemplate', {
              NAME: this.nameInputValue,
              ID: this.idInputValue,
              TYPE: this.typeInputValue,
              DOCUMENT: fileArray,
            });
          } catch (e) {
            DialogServiceCustom.showErrorBackend(e);
          }
        });
      } else {
        try {
          await Http.post('/updateDocumentsTemplate', {
            NAME: this.nameInputValue,
            ID: this.idInputValue,
            TYPE: this.typeInputValue,
            DOCUMENT: null,
          });
        } catch (e) {
          DialogServiceCustom.showErrorBackend(e);
        }
      }
      LoadingService.hide();
      this.closeModal();
      this.tekGridInstance.reload();
    }

    public downloadFileGrid(params: any) {
      this.baseUrl = Config.env.endPoint;
      debugger;
        const downloadUri = `${this.baseUrl}/downLoadAttachment?ID=${params.row.ATTACHMENT_ID}`;
        window.open(downloadUri);
    }

    public updateDetails() {
        setTimeout(() => {
        const { currentRow } = this.tekGridInstance.datasource;
        this.idInputValue = currentRow.ID;
        this.createdByInputValue = currentRow.CREATED_BY;
        this.createdAtInputValue = currentRow.CREATED_AT;
        this.nameInputValue = currentRow.NAME;
        this.typeInputValue = currentRow.TYPE;
        this.documentInputValue = currentRow.LABEL;
    }, 0);
    }
}
